==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/InitialNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.InitialNode;
import io.ciera.tool.sql.ooaofooa.activity.InitialNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class InitialNodeSetImpl extends InstanceSet<InitialNodeSet,InitialNode> implements InitialNodeSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( InitialNode initialnode : this ) initialnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( InitialNode initialnode : this ) initialnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( InitialNode initialnode : this ) controlnodeset.add( initialnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public InitialNode nullElement() {
        return InitialNodeImpl.EMPTY_INITIALNODE;
    }

    @Override
    public InitialNodeSet emptySet() {
      return new InitialNodeSetImpl();
    }

    @Override
    public InitialNodeSet value() {
        return this;
    }

    @Override
    public List<InitialNode> elements() {
        return Arrays.asList(toArray(new InitialNode[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/InitialNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.InitialNode;
import io.ciera.tool.sql.ooaofooa.activity.InitialNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InitialNodeSetImpl extends InstanceSet<InitialNodeSet,InitialNode> implements InitialNodeSet {

    public InitialNodeSetImpl() {
    }

    public InitialNodeSetImpl(Comparator<? super InitialNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( InitialNode initialnode : this ) initialnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( InitialNode initialnode : this ) initialnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( InitialNode initialnode : this ) controlnodeset.add( initialnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public InitialNode nullElement() {
        return InitialNodeImpl.EMPTY_INITIALNODE;
    }

    @Override
    public InitialNodeSet emptySet() {
      return new InitialNodeSetImpl();
    }

    @Override
    public InitialNodeSet emptySet(Comparator<? super InitialNode> comp) {
      return new InitialNodeSetImpl(comp);
    }

    @Override
    public InitialNodeSet value() {
        return this;
    }

    @Override
    public List<InitialNode> elements() {
        return Arrays.asList(toArray(new InitialNode[0]));
    }

}
